@@ -45,7 +45,7 @@
         <location filename="mainwindow.ui" line="231"/>
         <location filename="ui_mainwindow.h" line="764"/>
         <source>WiFi status</source>
-        <translation>Estado do WiFi</translation>
+        <translation>Estado do Wi-Fi</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="253"/>
@@ -57,7 +57,7 @@
         <location filename="mainwindow.ui" line="256"/>
         <location filename="ui_mainwindow.h" line="769"/>
         <source>Unblock WiFi Devices</source>
-        <translation>Desbloquear Dispositivos WiFi</translation>
+        <translation>Desbloquear Dispositivos Wi-Fi</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="288"/>
@@ -332,7 +332,7 @@
     <message>
         <location filename="mainwindow.cpp" line="900"/>
         <source>WiFi hardware switch is off</source>
-        <translation>O interruptor de WiFi do computador está deslidado</translation>
+        <translation>O interruptor de Wi-Fi do computador está desligado</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="908"/>
@@ -499,12 +499,12 @@
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
         <translation>Não foi possível desbloquear os dispositivos.
-O(s) dispositivo(s) WiFI podem já estar desbloqueados.</translation>
+O(s) dispositivo(s) Wi-FI podem já estar desbloqueados.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="997"/>
         <source>WiFi devices unlocked.</source>
-        <translation>Dispositivos WiFI desbloqueados</translation>
+        <translation>Dispositivos Wi-FI desbloqueados</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1040"/>
