@@ -1,491 +1,520 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_TW">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
 <context>
-    <name>MConfig</name>
+    <name>MainWindow</name>
     <message>
-        <location filename="../mconfig.cpp" line="157"/>
-        <source>IP address from router:</source>
-        <translation>自路由器所見之 IP 位址：</translation>
+        <location filename="mainwindow.ui" line="26"/>
+        <location filename="ui_mainwindow.h" line="756"/>
+        <source>Network Assistant</source>
+        <translation>網路助理</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="158"/>
-        <source>External IP address:</source>
-        <translation>自外部所見之 IP 位址：</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="295"/>
-        <location filename="../mconfig.cpp" line="309"/>
-        <location filename="../mconfig.cpp" line="323"/>
-        <source>&amp;Copy</source>
-        <translation>複製（&amp;C）</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="297"/>
-        <location filename="../mconfig.cpp" line="311"/>
-        <location filename="../mconfig.cpp" line="325"/>
-        <source>Ctrl+C</source>
-        <translation>Ctrl+C</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="298"/>
-        <location filename="../mconfig.cpp" line="312"/>
-        <location filename="../mconfig.cpp" line="326"/>
-        <source>Copy &amp;All</source>
-        <translation>複製全部（&amp;A）</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="300"/>
-        <location filename="../mconfig.cpp" line="314"/>
-        <location filename="../mconfig.cpp" line="328"/>
-        <source>Ctrl+A</source>
-        <translation>Ctrl+A</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="365"/>
-        <location filename="../mconfig.cpp" line="387"/>
-        <source>Traceroute not installed</source>
-        <translation>未安裝 traceroute</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="366"/>
-        <source>Traceroute is not installed, do you want to install it now?</source>
-        <translation>Traceroute 並未安裝，要現在安裝嗎？</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="374"/>
-        <source>Traceroute hasn&apos;t been installed</source>
-        <translation>未安裝 traceroute</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="375"/>
-        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
-        <translation>無法安裝 traceroute。這表示你正在使用現場版 CD，或者你無法連上軟體倉庫。</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="388"/>
-        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
-        <translation>Traceroute 並未安裝，此外，由於偵測不到網際網路連線，因此無法安裝。</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="395"/>
-        <location filename="../mconfig.cpp" line="447"/>
-        <source>No destination host</source>
-        <translation>無目標主機</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="396"/>
-        <location filename="../mconfig.cpp" line="448"/>
-        <source>Please fill in the destination host field</source>
-        <translation>請填寫目標主機欄位</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="579"/>
-        <source>Loaded Drivers</source>
-        <translation>已載入之驅動程式</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="589"/>
-        <source>Unloaded Drivers</source>
-        <translation>未載入之驅動程式</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="605"/>
-        <source>Blacklisted Drivers</source>
-        <translation>黑名單中的驅動程式</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="628"/>
-        <source>Blacklisted Broadcom Drivers</source>
-        <translation>黑名單中的 Broadcom 驅動程式</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1095"/>
-        <source>enabled</source>
-        <translation>使用中</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1098"/>
-        <source>disabled</source>
-        <translation>停用中</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1101"/>
-        <source>WiFi hardware switch is off</source>
-        <translation>WiFi 硬體的開關乃關閉狀態</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1109"/>
-        <source>Locate the Windows driver you want to add</source>
-        <translation>找出你想加入的 Windows 驅動程式</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1109"/>
-        <source>Windows installation information file (*.inf)</source>
-        <translation>Windows 安裝資訊檔（*.inf）</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1141"/>
-        <source>*.sys file not found</source>
-        <translation>找不到 *.sys 檔</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1141"/>
-        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
-        <translation>*.sys 檔的位置必須和 *.inf 檔相同。找不到 %1 。</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1152"/>
-        <source>sys file reference not found</source>
-        <translation>找不到指涉 sys 檔的內容</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1152"/>
-        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
-        <translation>分析該 inf 檔之後，無法確定該驅動程式的 sys 檔</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1171"/>
-        <source>Ndiswrapper driver removed.</source>
-        <translation>已移除 Ndiswrapper 驅動程式。</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1218"/>
-        <source>About MX Network Assistant</source>
-        <translation>關於 MX 網路助理</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1219"/>
-        <source>MX Network Assistant</source>
-        <translation>MX 網路助理</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1219"/>
-        <source>Version: </source>
-        <translation>版本：</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1221"/>
-        <source>Program for troubleshooting and configuring network for MX Linux</source>
-        <translation>本程式可在 MX Linux 中設定網路與排除障礙</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1222"/>
-        <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation>版權所有 (c) MEPIS LLC 暨 MX Linux</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1223"/>
-        <source>License</source>
-        <translation>授權條款</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1224"/>
-        <source>Changelog</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1225"/>
-        <source>Cancel</source>
-        <translation>取消</translation>
-    </message>
-    <message>
-        <location filename="../mconfig.cpp" line="1241"/>
-        <source>&amp;Close</source>
-        <translation>關閉（&amp;C）</translation>
-    </message>
-</context>
-<context>
-    <name>MEConfig</name>
-    <message>
-        <location filename="../meconfig.ui" line="26"/>
-        <source>MX Network Assistant</source>
-        <translation>MX 網路助理</translation>
-    </message>
-    <message>
-        <location filename="../meconfig.ui" line="71"/>
+        <location filename="mainwindow.ui" line="70"/>
+        <location filename="ui_mainwindow.h" line="770"/>
         <source>Status</source>
         <translation>狀態</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="77"/>
+        <location filename="mainwindow.ui" line="76"/>
+        <location filename="ui_mainwindow.h" line="757"/>
         <source>IP address</source>
         <translation>IP 位址</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="113"/>
+        <location filename="mainwindow.ui" line="112"/>
+        <location filename="ui_mainwindow.h" line="760"/>
         <source>Hardware detected</source>
         <translation>偵測到硬體</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="144"/>
-        <location filename="../meconfig.ui" line="392"/>
-        <location filename="../meconfig.ui" line="508"/>
+        <location filename="mainwindow.ui" line="143"/>
+        <location filename="mainwindow.ui" line="389"/>
+        <location filename="mainwindow.ui" line="502"/>
+        <location filename="ui_mainwindow.h" line="761"/>
+        <location filename="ui_mainwindow.h" line="774"/>
+        <location filename="ui_mainwindow.h" line="780"/>
         <source>Re-scan</source>
         <translation>重新掃描</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="217"/>
+        <location filename="mainwindow.ui" line="215"/>
+        <location filename="ui_mainwindow.h" line="762"/>
         <source>Active interface</source>
         <translation>使用中介面</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="233"/>
+        <location filename="mainwindow.ui" line="231"/>
+        <location filename="ui_mainwindow.h" line="764"/>
         <source>WiFi status</source>
         <translation>WiFi 狀態</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="255"/>
+        <location filename="mainwindow.ui" line="253"/>
+        <location filename="ui_mainwindow.h" line="767"/>
         <source>Unblocks all soft/hard blocked wireless devices</source>
         <translation>所有停用的無線設備，不論是可重新啟用或不可重新啟用者，皆取消停用</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="258"/>
+        <location filename="mainwindow.ui" line="256"/>
+        <location filename="ui_mainwindow.h" line="769"/>
         <source>Unblock WiFi Devices</source>
         <translation>將所有 WiFi 設備取消停用</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="291"/>
+        <location filename="mainwindow.ui" line="288"/>
+        <location filename="ui_mainwindow.h" line="776"/>
         <source>Linux drivers</source>
         <translation>Linux 的驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="303"/>
+        <location filename="mainwindow.ui" line="300"/>
+        <location filename="ui_mainwindow.h" line="771"/>
         <source>Associated Linux drivers</source>
         <translation>相關的 Linux 驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="312"/>
+        <location filename="mainwindow.ui" line="309"/>
+        <location filename="ui_mainwindow.h" line="772"/>
         <source>Load Driver</source>
         <translation>載入驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="375"/>
+        <location filename="mainwindow.ui" line="372"/>
+        <location filename="ui_mainwindow.h" line="773"/>
         <source>Unload Driver</source>
         <translation>卸載驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="413"/>
-        <source>Blacklist Driver</source>
-        <translation>將驅動程式列入黑名單</translation>
+        <location filename="mainwindow.ui" line="409"/>
+        <location filename="ui_mainwindow.h" line="775"/>
+        <source>Block Driver</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="432"/>
+        <location filename="mainwindow.ui" line="428"/>
+        <location filename="ui_mainwindow.h" line="785"/>
         <source>Windows drivers</source>
         <translation>Windows 的驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="438"/>
+        <location filename="mainwindow.ui" line="434"/>
+        <location filename="ui_mainwindow.h" line="777"/>
         <source>Available Windows drivers</source>
         <translation>可取用之 Windows 驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="472"/>
+        <location filename="mainwindow.ui" line="468"/>
+        <location filename="ui_mainwindow.h" line="778"/>
         <source>Remove Driver</source>
         <translation>移除驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="484"/>
+        <location filename="mainwindow.ui" line="479"/>
+        <location filename="ui_mainwindow.h" line="779"/>
         <source>Add Driver</source>
         <translation>新増驅動程式</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="527"/>
+        <location filename="mainwindow.ui" line="520"/>
+        <location filename="ui_mainwindow.h" line="781"/>
         <source>About NDISwrapper</source>
         <translation>關於 NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="539"/>
+        <location filename="mainwindow.ui" line="532"/>
+        <location filename="ui_mainwindow.h" line="782"/>
         <source>Install NDISwrapper</source>
         <translation>安裝 NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="551"/>
+        <location filename="mainwindow.ui" line="543"/>
+        <location filename="ui_mainwindow.h" line="783"/>
         <source>In order to use Windows drivers you need first to install NDISwrapper</source>
         <translation>欲使用 Windows 的驅動程式，必須先安裝 NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="567"/>
+        <location filename="mainwindow.ui" line="559"/>
+        <location filename="ui_mainwindow.h" line="784"/>
         <source>Uninstall NDISwrapper</source>
         <translation>移除 NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="600"/>
+        <location filename="mainwindow.ui" line="591"/>
+        <location filename="ui_mainwindow.h" line="798"/>
         <source>Net diagnostics</source>
         <translation>網路狀態診斷</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="612"/>
+        <location filename="mainwindow.ui" line="603"/>
+        <location filename="ui_mainwindow.h" line="786"/>
         <source>Ping</source>
         <translation>Ping</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="618"/>
-        <location filename="../meconfig.ui" line="730"/>
+        <location filename="mainwindow.ui" line="609"/>
+        <location filename="mainwindow.ui" line="726"/>
+        <location filename="ui_mainwindow.h" line="787"/>
+        <location filename="ui_mainwindow.h" line="793"/>
         <source>Target URL:</source>
         <translation>目標 URL：</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="628"/>
+        <location filename="mainwindow.ui" line="619"/>
+        <location filename="ui_mainwindow.h" line="788"/>
         <source>Packets</source>
         <translation>封包數</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="663"/>
-        <location filename="../meconfig.ui" line="785"/>
+        <location filename="mainwindow.ui" line="661"/>
+        <location filename="mainwindow.ui" line="781"/>
+        <location filename="ui_mainwindow.h" line="789"/>
+        <location filename="ui_mainwindow.h" line="795"/>
         <source>Start</source>
         <translation>開始</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="681"/>
-        <location filename="../meconfig.ui" line="803"/>
+        <location filename="mainwindow.ui" line="678"/>
+        <location filename="mainwindow.ui" line="798"/>
+        <location filename="ui_mainwindow.h" line="790"/>
+        <location filename="ui_mainwindow.h" line="796"/>
         <source>Clear</source>
         <translation>清除</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="696"/>
-        <location filename="../meconfig.ui" line="818"/>
+        <location filename="mainwindow.ui" line="692"/>
+        <location filename="mainwindow.ui" line="812"/>
+        <location filename="ui_mainwindow.h" line="791"/>
+        <location filename="ui_mainwindow.h" line="797"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="724"/>
+        <location filename="mainwindow.ui" line="720"/>
+        <location filename="ui_mainwindow.h" line="792"/>
         <source>Traceroute</source>
         <translation>Traceroute</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="740"/>
+        <location filename="mainwindow.ui" line="736"/>
+        <location filename="ui_mainwindow.h" line="794"/>
         <source>Hops</source>
         <translation>中繼點</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="772"/>
-        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
-&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
-p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Droid Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
-&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
-p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Droid Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="../meconfig.ui" line="868"/>
+        <location filename="mainwindow.ui" line="868"/>
+        <location filename="ui_mainwindow.h" line="799"/>
         <source>About...</source>
         <translation>關於……</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="886"/>
+        <location filename="mainwindow.ui" line="891"/>
+        <location filename="ui_mainwindow.h" line="803"/>
         <source>Help</source>
         <translation>說明</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="949"/>
+        <location filename="mainwindow.ui" line="959"/>
+        <location filename="ui_mainwindow.h" line="805"/>
         <source>&amp;Close</source>
         <translation>關閉（&amp;C）</translation>
     </message>
     <message>
-        <location filename="../meconfig.ui" line="957"/>
+        <location filename="mainwindow.ui" line="966"/>
+        <location filename="ui_mainwindow.h" line="807"/>
         <source>Alt+C</source>
         <translation>Alt+C</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="87"/>
+        <source>IP address from router:</source>
+        <translation>自路由器所見之 IP 位址：</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="88"/>
+        <source>External IP address:</source>
+        <translation>自外部所見之 IP 位址：</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="196"/>
+        <location filename="mainwindow.cpp" line="210"/>
+        <location filename="mainwindow.cpp" line="224"/>
+        <source>&amp;Copy</source>
+        <translation>複製（&amp;C）</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="198"/>
+        <location filename="mainwindow.cpp" line="212"/>
+        <location filename="mainwindow.cpp" line="226"/>
+        <source>Ctrl+C</source>
+        <translation>Ctrl+C</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="199"/>
+        <location filename="mainwindow.cpp" line="213"/>
+        <location filename="mainwindow.cpp" line="227"/>
+        <source>Copy &amp;All</source>
+        <translation>複製全部（&amp;A）</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="201"/>
+        <location filename="mainwindow.cpp" line="215"/>
+        <location filename="mainwindow.cpp" line="229"/>
+        <source>Ctrl+A</source>
+        <translation>Ctrl+A</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="261"/>
+        <location filename="mainwindow.cpp" line="278"/>
+        <source>Traceroute not installed</source>
+        <translation>未安裝 traceroute</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="262"/>
+        <source>Traceroute is not installed, do you want to install it now?</source>
+        <translation>Traceroute 並未安裝，要現在安裝嗎？</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="269"/>
+        <source>Traceroute hasn&apos;t been installed</source>
+        <translation>未安裝 traceroute</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="270"/>
+        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
+        <translation>無法安裝 traceroute。這表示你正在使用現場版 CD，或者你無法連上軟體倉庫。</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="279"/>
+        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
+        <translation>Traceroute 並未安裝，此外，由於偵測不到網際網路連線，因此無法安裝。</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="285"/>
+        <location filename="mainwindow.cpp" line="326"/>
+        <source>No destination host</source>
+        <translation>無目標主機</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="286"/>
+        <location filename="mainwindow.cpp" line="327"/>
+        <source>Please fill in the destination host field</source>
+        <translation>請填寫目標主機欄位</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="440"/>
+        <source>Loaded Drivers</source>
+        <translation>已載入之驅動程式</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="449"/>
+        <source>Unloaded Drivers</source>
+        <translation>未載入之驅動程式</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="464"/>
+        <source>Blocked Drivers</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="486"/>
+        <source>Blocked Broadcom Drivers</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="894"/>
+        <source>enabled</source>
+        <translation>使用中</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="897"/>
+        <source>disabled</source>
+        <translation>停用中</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="900"/>
+        <source>WiFi hardware switch is off</source>
+        <translation>WiFi 硬體的開關乃關閉狀態</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="908"/>
+        <source>Locate the Windows driver you want to add</source>
+        <translation>找出你想加入的 Windows 驅動程式</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="908"/>
+        <source>Windows installation information file (*.inf)</source>
+        <translation>Windows 安裝資訊檔（*.inf）</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="939"/>
+        <source>*.sys file not found</source>
+        <translation>找不到 *.sys 檔</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="939"/>
+        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
+        <translation>*.sys 檔的位置必須和 *.inf 檔相同。找不到 %1 。</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="948"/>
+        <source>sys file reference not found</source>
+        <translation>找不到指涉 sys 檔的內容</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="948"/>
+        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
+        <translation>分析該 inf 檔之後，無法確定該驅動程式的 sys 檔</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="967"/>
+        <source>Ndiswrapper driver removed.</source>
+        <translation>已移除 Ndiswrapper 驅動程式。</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="975"/>
+        <source>%1 Help</source>
+        <translation>%1 幫助</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="1012"/>
+        <source>About %1</source>
+        <translation>大約 %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="1013"/>
+        <source>Version: </source>
+        <translation>版本：</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="1014"/>
+        <source>Program for troubleshooting and configuring network for antiX Linux</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="1016"/>
+        <source>Copyright (c) MEPIS LLC and MX Linux</source>
+        <translation>版權所有 (c) MEPIS LLC 暨 MX Linux</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="1017"/>
+        <source>%1 License</source>
+        <translation>%1 許可</translation>
+    </message>
 </context>
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../main.cpp" line="44"/>
+        <location filename="about.cpp" line="32"/>
+        <source>License</source>
+        <translation>授權條款</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
+        <source>Changelog</source>
+        <translation>變更紀錄</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="34"/>
+        <source>Cancel</source>
+        <translation>取消</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="51"/>
+        <source>&amp;Close</source>
+        <translation>關閉（&amp;C）</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="44"/>
         <source>You must run this program as root.</source>
         <translation>本程式必須以 root 身份來執行。</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="651"/>
+        <location filename="mainwindow.cpp" line="509"/>
         <source>Ndiswrapper is not installed</source>
         <translation>未安裝 Ndiswrapper</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="660"/>
+        <location filename="mainwindow.cpp" line="521"/>
         <source>driver installed</source>
         <translation>驅動程式已安裝</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="671"/>
+        <location filename="mainwindow.cpp" line="529"/>
         <source> and in use by </source>
         <translation>並且正被下述程序使用：</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="680"/>
+        <location filename="mainwindow.cpp" line="536"/>
         <source>. Alternate driver: </source>
         <translation>。亦可改用此驅動程式：</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="772"/>
-        <source>Driver removed from blacklist</source>
-        <translation>已從黑名單中移除該驅動程式</translation>
+        <location filename="mainwindow.cpp" line="613"/>
+        <source>Driver removed from blocklist</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="773"/>
-        <source>Driver removed from blacklist.</source>
-        <translation>已從黑名單中移除該驅動程式。</translation>
+        <location filename="mainwindow.cpp" line="614"/>
+        <source>Driver removed from blocklist.</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="781"/>
-        <location filename="../mconfig.cpp" line="782"/>
-        <source>Module blacklisted</source>
-        <translation>已將該模組列入黑名單</translation>
+        <location filename="mainwindow.cpp" line="620"/>
+        <location filename="mainwindow.cpp" line="621"/>
+        <source>Module blocked</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="975"/>
+        <location filename="mainwindow.cpp" line="786"/>
         <source>Installation successful</source>
         <translation>安裝成功</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="979"/>
+        <location filename="mainwindow.cpp" line="789"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
         <translation>偵測到錯誤，無法編譯 ndiswrapper 驅動程式。</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="984"/>
+        <location filename="mainwindow.cpp" line="792"/>
         <source>Error detected, could not install ndiswrapper.</source>
         <translation>偵測到錯誤，無法安裝 ndiswrapper。</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="996"/>
+        <location filename="mainwindow.cpp" line="804"/>
         <source>Error encountered while removing Ndiswrapper</source>
         <translation>移除 Ndiswrapper 時發生錯誤</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="1054"/>
-        <source>Unblacklist Driver</source>
-        <translation>將驅動程式從黑名單中移除</translation>
+        <location filename="mainwindow.cpp" line="855"/>
+        <source>Unblock Driver</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="1059"/>
-        <source>Blacklist Driver</source>
-        <translation>將驅動程式列入黑名單</translation>
+        <location filename="mainwindow.cpp" line="858"/>
+        <source>Block Driver</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="1200"/>
+        <location filename="mainwindow.cpp" line="995"/>
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
         <translation>無法取消停用該設備。
 也許這個（這些）設備本來就未停用。</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="1202"/>
+        <location filename="mainwindow.cpp" line="997"/>
         <source>WiFi devices unlocked.</source>
         <translation>取消停用該 WiFi 設備。</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="1275"/>
-        <location filename="../mconfig.cpp" line="1276"/>
+        <location filename="mainwindow.cpp" line="1040"/>
+        <location filename="mainwindow.cpp" line="1041"/>
         <source>Driver loaded successfully</source>
         <translation>順利載入驅動程式</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="1294"/>
-        <location filename="../mconfig.cpp" line="1295"/>
+        <location filename="mainwindow.cpp" line="1056"/>
+        <location filename="mainwindow.cpp" line="1057"/>
         <source>Driver unloaded successfully</source>
         <translation>順利卸載驅動程式</translation>
     </message>
@@ -493,14 +522,14 @@ WiFi device(s) might already be unlocked.</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mconfig.cpp" line="801"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Could not load </source>
         <translation>無法載入</translation>
     </message>
     <message>
-        <location filename="../mconfig.cpp" line="837"/>
+        <location filename="mainwindow.cpp" line="669"/>
         <source>Could not unload </source>
         <translation>無法卸載</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
